MethodChannelFlutterGeminiNano class

Android implementation of the flutter_gemini_nano plugin.

Uses a MethodChannel to communicate with the native Android layer responsible for interacting with Android AI Core and executing Gemini Nano.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

geminiNano({required String prompt, Uint8List? imageBytes, double? temperature, int? seed, int? topK, int? candidateCount, int? maxOutputTokens}) Future<Map<String, dynamic>>
Executes a Gemini Nano request on the underlying platform.
override
isGeminiNanoAvailable() Future<bool>
Checks whether Gemini Nano is available on the current device.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited